( cd sbin ; rm -rf fsck.jfs )
( cd sbin ; ln -sf jfs_fsck fsck.jfs )
( cd sbin ; rm -rf mkfs.jfs )
( cd sbin ; ln -sf jfs_mkfs mkfs.jfs )
( cd usr/man/man8 ; rm -rf fsck.jfs.8.gz )
( cd usr/man/man8 ; ln -sf jfs_fsck.8.gz fsck.jfs.8.gz )
( cd usr/man/man8 ; rm -rf mkfs.jfs.8.gz )
( cd usr/man/man8 ; ln -sf jfs_mkfs.8.gz mkfs.jfs.8.gz )
